@@ -27,9 +27,9 @@
 A module containing various converter implementations as well as logic for
 registering and selecting them.
 
-@author: jmoringe
-@author: jwienke
-@author: plueckin
+.. codeauthor:: jmoringe
+.. codeauthor:: jwienke
+.. codeauthor:: plueckin
 """
 
 from numbers import Integral, Real
@@ -39,28 +39,27 @@ from rsb.transport.conversion import notificationToEvent, eventToNotification
 from rsb import Scope
 from threading import RLock
 
+
 class Converter(object):
     """
     Base class for converters to a certain target type.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, wireType, dataType, wireSchema):
         """
         Constructor.
 
-        @param wireType: Python type to/from which the converter
-                         serializes/deserializes
-        @type wireType: type
-        @param dataType: Python type of data accepted by the converter
-                         for serialization (also Python type of
-                         deserialized data)
-        @type dataType: type
-        @param wireSchema: Wire-schema understood by the converter
-                           when deserializing (also wire-schema of
-                           data serialized with the converter)
-        @type wireSchema: str
+        Args:
+            wireType (types.TypeType):
+                Python type to/from which the converter serializes/deserializes
+            dataType (types.TypeType):
+                Python type of data accepted by the converter for serialization
+                (also Python type of deserialized data)
+            wireSchema (str):
+                Wire-schema understood by the converter when deserializing
+                (also wire-schema of data serialized with the converter)
         """
         self.__wireType = wireType
         self.__dataType = dataType
@@ -71,8 +70,9 @@ class Converter(object):
         Returns the type of the wire-type to/from this converter
         serializes/deserializes.
 
-        @return: A type object.
-        @rtype: type
+        Returns:
+            types.TypeType:
+                A type object.
         """
         return self.__wireType
 
@@ -82,8 +82,9 @@ class Converter(object):
         """
         Returns the data type this converter is applicable for.
 
-        @return: A type object.
-        @rtype: type
+        Returns:
+            types.TypeType:
+                A type object.
         """
         return self.__dataType
 
@@ -91,12 +92,13 @@ class Converter(object):
 
     def getWireSchema(self):
         """
-        Returns the name of the wire schema this converter can
-        (de)serialize from/to.
+        Returns the name of the wire schema this converter can (de)serialize
+        from/to.
 
-        @return: A string designating the wire schema from/to this
-                 converter can (de)serialize
-        @rtype: str
+        Returns:
+            str:
+                A string designating the wire schema from/to this converter can
+                (de)serialize
         """
         return self.__wireSchema
 
@@ -108,22 +110,25 @@ class Converter(object):
     def deserialize(self, inp, wireSchema):
         raise NotImplementedError()
 
+
 class UnknownConverterError(KeyError):
     """
-    Raised if a converter for a target type is not available.
-
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, sourceType, wireSchema):
-        KeyError.__init__(self, "No converter from type %s to type %s available" % (sourceType, wireSchema))
+        KeyError.__init__(
+            self,
+            "No converter from type %s to type %s available" % (sourceType,
+                                                                wireSchema))
+
 
 class ConverterSelectionStrategy(object):
     """
     This class defines the interface for converter selection strategy
     classes.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
     def hasConverterForWireSchema(self, wireSchema):
         if self._getConverterForWireSchema(wireSchema):
@@ -135,7 +140,7 @@ class ConverterSelectionStrategy(object):
         converter = self._getConverterForWireSchema(wireSchema)
         if converter:
             return converter
-        raise KeyError, wireSchema
+        raise KeyError(wireSchema)
 
     def hasConverterForDataType(self, dataType):
         if self._getConverterForDataType(dataType):
@@ -147,13 +152,14 @@ class ConverterSelectionStrategy(object):
         converter = self._getConverterForDataType(dataType)
         if converter:
             return converter
-        raise KeyError, dataType
+        raise KeyError(dataType)
+
 
 class ConverterMap(ConverterSelectionStrategy):
     """
     A class managing converters for for a certain target type.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, wireType):
@@ -166,7 +172,8 @@ class ConverterMap(ConverterSelectionStrategy):
     def addConverter(self, converter, replaceExisting=False):
         key = (converter.getWireSchema(), converter.getDataType())
         if key in self._converters and not replaceExisting:
-            raise RuntimeError("There already is a converter with wire-schema `%s' and data-type `%s'"
+            raise RuntimeError("There already is a converter "
+                               "with wire-schema `%s' and data-type `%s'"
                                % key)
         self._converters[key] = converter
 
@@ -190,7 +197,7 @@ class ConverterMap(ConverterSelectionStrategy):
                 else:
                     return 1
             return sorted(candidates, compareViaSubclass,
-                          key = lambda x: x.getDataType())[0]
+                          key=lambda x: x.getDataType())[0]
 
     def getConverters(self):
         return self._converters
@@ -198,10 +205,12 @@ class ConverterMap(ConverterSelectionStrategy):
     def __str__(self):
         s = "ConverterMap(wireType = %s):\n" % self._wireType
         for converter in self._converters.values():
-            s = s + ("\t%s <-> %s\n" % (converter.getWireSchema(), converter.getDataType()))
+            s = s + ("\t%s <-> %s\n" % (converter.getWireSchema(),
+                                        converter.getDataType()))
         return s[:-1]
 
-class PredicateConverterList (ConverterMap):
+
+class PredicateConverterList(ConverterMap):
     """
     Objects of this class are used to perform converter selection via
     a chain-of-responsibility strategy.
@@ -212,9 +221,9 @@ class PredicateConverterList (ConverterMap):
     associated predicate of which matches the query wire-schema or
     data-type.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
-    def __init__(self, wireType) :
+    def __init__(self, wireType):
         super(PredicateConverterList, self).__init__(wireType)
         self._list = []
 
@@ -226,9 +235,11 @@ class PredicateConverterList (ConverterMap):
             # if converter.getWireSchema() == 'void':
             #    wireSchemaPredicate = lambda wireSchema: True
             # else:
-                wireSchemaPredicate = lambda wireSchema: wireSchema == converter.getWireSchema()
+            wireSchemaPredicate = lambda wireSchema: \
+                wireSchema == converter.getWireSchema()
         if dataTypePredicate is None:
-            dataTypePredicate = lambda dataType: dataType == converter.getDataType()
+            dataTypePredicate = lambda dataType: \
+                dataType == converter.getDataType()
         key = (wireSchemaPredicate, dataTypePredicate)
         self._converters[key] = converter
         self._list.append((key, converter))
@@ -243,7 +254,8 @@ class PredicateConverterList (ConverterMap):
             if predicate(dataType):
                 return converter
 
-class UnambiguousConverterMap (ConverterMap):
+
+class UnambiguousConverterMap(ConverterMap):
     def __init__(self, wireType):
         super(UnambiguousConverterMap, self).__init__(wireType)
 
@@ -251,51 +263,65 @@ class UnambiguousConverterMap (ConverterMap):
         for (wireSchema, dataType) in self.getConverters().keys():
             if wireSchema == converter.getWireSchema():
                 if dataType == converter.getDataType():
-                    super(UnambiguousConverterMap, self).addConverter(converter, replaceExisting)
+                    super(UnambiguousConverterMap, self).addConverter(
+                        converter, replaceExisting)
                 else:
-                    raise RuntimeError("Trying to register ambiguous converter with data type `%s' for wire-schema `%s' (present converter is for data type `%s')."
-                                       % (converter.getDataType(), wireSchema, dataType))
-        super(UnambiguousConverterMap, self).addConverter(converter, replaceExisting)
+                    raise RuntimeError(
+                        "Trying to register ambiguous converter "
+                        "with data type `%s' for wire-schema `%s' "
+                        "(present converter is for data type `%s')."
+                        % (converter.getDataType(),
+                           wireSchema,
+                           dataType))
+        super(UnambiguousConverterMap, self).addConverter(
+            converter, replaceExisting)
 
 __globalConverterMapsLock = RLock()
 __globalConverterMaps = {}
 
+
 def registerGlobalConverter(converter, replaceExisting=False):
     """
-    Register B{converter} as a globally available converter.
+    Register ``converter`` as a globally available converter.
 
-    @param converter: converter to register
-    @param replaceExisting: controls whether an existing converter for
-                            the same data-type and/or wire-type should
-                            be replaced by the new converter. If this
-                            is C{False} and such a converter exists,
-                            an error is raised.
+    Args:
+        converter:
+            converter to register
+        replaceExisting:
+            controls whether an existing converter for the same data-type
+            and/or wire-type should be replaced by the new converter. If this
+            is ``False`` and such a converter exists, an error is raised.
     """
     mapForWireType = getGlobalConverterMap(converter.getWireType())
     mapForWireType.addConverter(converter, replaceExisting)
 
+
 def getGlobalConverterMap(wireType):
     """
-    Get a map with all globally known converters for the B{wireType}.
+    Get a map with all globally known converters for the ``wireType``.
 
-    @param wireType: Python type for designating the wire-type.
-    @type wireType: type
-    @return: converter map constantly updated
+    Args:
+        wireType (types.TypeType):
+            Python type for designating the wire-type.
+
+    Returns:
+        converter map constantly updated
     """
 
     with __globalConverterMapsLock:
-        if not wireType in __globalConverterMaps:
+        if wireType not in __globalConverterMaps:
             __globalConverterMaps[wireType] = ConverterMap(wireType)
         return __globalConverterMaps[wireType]
 
 # --- converters with bytearray as serialization type ---
 
-class IdentityConverter (Converter):
+
+class IdentityConverter(Converter):
     """
     This converter does nothing. Use it in combination with the
     "AlwaysApplicable"-wireSchema.
 
-    @author: plueckin
+    .. codeauthor:: plueckin
     """
     def __init__(self):
         super(IdentityConverter, self).__init__(bytearray, type(None), 'void')
@@ -309,15 +335,16 @@ class IdentityConverter (Converter):
     def AlwaysApplicable(self):
         return bytearray
 
-class NoneConverter (Converter):
+
+class NoneConverter(Converter):
     """
     This converter produces a serialized value that represents
-    instances of C{NoneType}.
+    instances of ``NoneType``.
 
     Such a converter is required for serializing "results" of RPC
     calls that do not return a value.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
     def __init__(self):
         super(NoneConverter, self).__init__(bytearray, type(None), 'void')
@@ -328,12 +355,12 @@ class NoneConverter (Converter):
     def deserialize(self, inp, wireSchema):
         assert wireSchema == self.wireSchema
 
-        pass
 
 def makeStructBasedConverter(name, dataType, wireSchema, fmt, size):
     class NewConverter(Converter):
         def __init__(self):
-            super(self.__class__, self).__init__(bytearray, dataType, wireSchema)
+            super(self.__class__, self).__init__(
+                bytearray, dataType, wireSchema)
 
         def serialize(self, inp):
             return bytearray(struct.pack(fmt, inp)), self.wireSchema
@@ -345,9 +372,10 @@ def makeStructBasedConverter(name, dataType, wireSchema, fmt, size):
     NewConverter.__name__ = name
     # TODO(jmoringe): seems to be impossible in CPython
     # NewConverter.__doc__ = """
-    # A converter that serializes %(dataType)s to bytearrays with %(wireSchema)s wire-schema.
+    # A converter that serializes %(dataType)s to bytearrays with
+    # %(wireSchema)s wire-schema.
     #
-    # @author: jmoringe
+    # .. codeauthor:: jmoringe
     # """ % {
     #     "dataType":   dataType,
     #     "wireSchema": wireSchema
@@ -364,12 +392,13 @@ makeStructBasedConverter('Uint64Converter', Integral, 'uint64', '<Q', 8)
 makeStructBasedConverter('Int64Converter', Integral, 'int64', '<q', 8)
 makeStructBasedConverter('BoolConverter', bool, 'bool', '?', 1)
 
+
 # Registered at end of file
 class BytesConverter(Converter):
     """
     Handles byte arrays.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self, wireSchema="bytes", dataType=bytearray):
@@ -382,15 +411,19 @@ class BytesConverter(Converter):
         assert(wireSchema == self.wireSchema)
         return inp
 
+
 class StringConverter(Converter):
     """
     A converter that serializes strings to bytearrays with a specified
     encoding
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
-    def __init__(self, wireSchema="utf-8-string", dataType=unicode, encoding="utf_8"):
+    def __init__(self,
+                 wireSchema="utf-8-string",
+                 dataType=unicode,
+                 encoding="utf_8"):
         super(StringConverter, self).__init__(bytearray, dataType, wireSchema)
         self.__encoding = encoding
 
@@ -406,11 +439,12 @@ class StringConverter(Converter):
         else:
             raise ValueError("Inacceptable dataType %s" % type)
 
+
 class ByteArrayConverter(Converter):
     """
     A converter which just passes through the original byte array of a message.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
     def __init__(self):
         super(ByteArrayConverter, self).__init__(bytearray, bytearray, '.*')
@@ -421,15 +455,17 @@ class ByteArrayConverter(Converter):
     def deserialize(self, data, wireSchema):
         return bytearray(data)
 
+
 class SchemaAndByteArrayConverter(Converter):
     """
     A converter which passes through the wireSchema as well as the original
     byte array of a message.
 
-    @author: nkoester
+    .. codeauthor:: nkoester
     """
     def __init__(self):
-        super(SchemaAndByteArrayConverter, self).__init__(bytearray, tuple, '.*')
+        super(SchemaAndByteArrayConverter, self).__init__(
+            bytearray, tuple, '.*')
 
     def serialize(self, data):
         return data[1], data[0]
@@ -437,6 +473,7 @@ class SchemaAndByteArrayConverter(Converter):
     def deserialize(self, data, wireSchema):
         return wireSchema, data
 
+
 class ProtocolBufferConverter(Converter):
     """
     This converter serializes and deserializes objects of protocol
@@ -445,12 +482,11 @@ class ProtocolBufferConverter(Converter):
     These data-holder classes are generated by the protocol buffer
     compiler protoc.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
     def __init__(self, messageClass):
-        super(ProtocolBufferConverter, self).__init__(bytearray,
-                                                      messageClass,
-                                                      '.%s' % messageClass.DESCRIPTOR.full_name)
+        super(ProtocolBufferConverter, self).__init__(
+            bytearray, messageClass, '.%s' % messageClass.DESCRIPTOR.full_name)
 
         self.__messageClass = messageClass
 
@@ -481,19 +517,21 @@ class ProtocolBufferConverter(Converter):
     def __repr__(self):
         return str(self)
 
+
 class EventsByScopeMapConverter(Converter):
     """
     A converter for aggregated events ordered by their scope and time for each
     scope. As a client data type dictionaries are used. Think about this when
     you register the converter and also have other dictionaries to transmit.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, converterRepository=getGlobalConverterMap(bytearray)):
         self.__converterRepository = converterRepository
         self.__converter = ProtocolBufferConverter(EventsByScopeMap)
-        super(EventsByScopeMapConverter, self).__init__(bytearray, dict, self.__converter.wireSchema)
+        super(EventsByScopeMapConverter, self).__init__(
+            bytearray, dict, self.__converter.wireSchema)
 
     def serialize(self, data):
 
@@ -506,10 +544,13 @@ class EventsByScopeMapConverter(Converter):
 
             for event in events:
 
-                wire, wireSchema = self.__converterRepository.getConverterForDataType(type(event.data)).serialize(event.data)
+                wire, wireSchema = \
+                    self.__converterRepository.getConverterForDataType(
+                        type(event.data)).serialize(event.data)
 
                 notification = scopeSet.notifications.add()
-                eventToNotification(notification, event, wireSchema, wire, True)
+                eventToNotification(notification, event,
+                                    wireSchema, wire, True)
 
         return self.__converter.serialize(eventMap)
 
@@ -523,8 +564,12 @@ class EventsByScopeMapConverter(Converter):
             output[scope] = []
             for notification in scopeSet.notifications:
 
-                converter = self.__converterRepository.getConverterForWireSchema(notification.wire_schema)
-                event = notificationToEvent(notification, notification.data, notification.wire_schema, converter)
+                converter = \
+                    self.__converterRepository.getConverterForWireSchema(
+                        notification.wire_schema)
+                event = notificationToEvent(
+                    notification, notification.data,
+                    notification.wire_schema, converter)
 
                 output[scope].append(event)
 
@@ -534,12 +579,13 @@ class EventsByScopeMapConverter(Converter):
 # ambiguities.
 registerGlobalConverter(NoneConverter())
 registerGlobalConverter(DoubleConverter())
-#registerGlobalConverter(FloatConverter())
-#registerGlobalConverter(Uint32Converter())
-#registerGlobalConverter(Int32Converter())
-#registerGlobalConverter(Uint64Converter())
+# registerGlobalConverter(FloatConverter())
+# registerGlobalConverter(Uint32Converter())
+# registerGlobalConverter(Int32Converter())
+# registerGlobalConverter(Uint64Converter())
 registerGlobalConverter(Int64Converter())
 registerGlobalConverter(BoolConverter())
 registerGlobalConverter(BytesConverter())
-registerGlobalConverter(StringConverter(wireSchema="utf-8-string", dataType=str, encoding="utf_8"))
+registerGlobalConverter(StringConverter(wireSchema="utf-8-string",
+                                        dataType=str, encoding="utf_8"))
 registerGlobalConverter(ByteArrayConverter())
