@@ -31,13 +31,14 @@ and thus built on top of "ordinary" RSB communication.
 This package implements the "local introspection" (i.e. introspection
 sender) part of the introspection architecture.
 
-@author: jmoringe
+.. codeauthor:: jmoringe
 """
 
 import sys
 import os
 import platform
 
+import copy
 import uuid
 
 import rsb
@@ -52,22 +53,25 @@ _displayName = None
 
 # Model
 
-class ParticipantInfo (object):
+
+class ParticipantInfo(object):
     """
     Instances of this class store information about a participant.
 
     The participant can reside in the current process or in a remote
     process.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
-    def __init__(self, kind, id, scope, type, parentId = None):
-        self.__kind  = kind
-        self.__id    = id
+    def __init__(self, kind, id, scope, type, parentId=None,
+                 transportURLs=None):
+        self.__kind = kind
+        self.__id = id
         self.__scope = rsb.Scope.ensureScope(scope)
-        self.__type  = type
+        self.__type = type
         self.__parentId = parentId
+        self.__transportURLs = transportURLs or []
 
     def getKind(self):
         """
@@ -75,9 +79,10 @@ class ParticipantInfo (object):
 
         Examples include "listener", "informer" and "local-server".
 
-        @return: A lower-case, hyphen-separated string identifying the
-                 kind of participant.
-        @rtype: str
+        Returns:
+            str:
+                A lower-case, hyphen-separated string identifying the kind of
+                participant.
         """
         return self.__kind
 
@@ -87,8 +92,9 @@ class ParticipantInfo (object):
         """
         Returns the unique id of the participant.
 
-        @return: The unique id of the participant.
-        @rtype: uuid.uuid
+        Returns:
+            uuid.uuid:
+                The unique id of the participant.
         """
         return self.__id
 
@@ -98,8 +104,9 @@ class ParticipantInfo (object):
         """
         Returns the scope of the participant.
 
-        @return: The scope of the participant.
-        @rtype: rsb.Scope
+        Returns:
+            rsb.Scope:
+                The scope of the participant.
         """
         return self.__scope
 
@@ -113,8 +120,9 @@ class ParticipantInfo (object):
         Note that this is a temporary solution and will change in
         future versions.
 
-        @return: A representation of the type.
-        @rtype: type or tuple
+        Returns:
+            type or tuple:
+                A representation of the type.
         """
         return self.__type
 
@@ -123,15 +131,29 @@ class ParticipantInfo (object):
     def getParentId(self):
         """
         Return the unique id of the parent participant of the participant,
-        or C{None}, if the participant does not have a parent.
+        or ``None``, if the participant does not have a parent.
 
-        @return: C{None} or the unique id of the participant's parent.
-        @rtype: uuid.uuid or NoneType
+        Returns:
+            uuid.uuid or NoneType:
+                ``None`` or the unique id of the participant's parent.
         """
         return self.__parentId
 
     parentId = property(getParentId)
 
+    def getTransportURLs(self):
+        """
+        Return list of transport URLs.
+
+        Returns:
+            list:
+                List of transport URLs describing the transports used
+                by the participant.
+        """
+        return self.__transportURLs
+
+    transportURLs = property(getTransportURLs)
+
     def __str__(self):
         return '<%s %s %s at 0x%0x>' \
             % (type(self).__name__, self.kind, self.scope.toString(), id(self))
@@ -141,18 +163,20 @@ class ParticipantInfo (object):
 
 __processStartTime = None
 
+
 def processStartTime():
     """
     Return the start time of the current process (or an approximation)
     in fractional seconds since UNIX epoch.
 
-    @return: Start time in factional seconds since UNIX epoch.
-    @rtype: float
+    Returns:
+        float:
+            Start time in factional seconds since UNIX epoch.
     """
     global __processStartTime
 
     # Used cached value, if there is one.
-    if not __processStartTime is None:
+    if __processStartTime is not None:
         return __processStartTime
 
     # Try to determine the start time of the current process in a
@@ -164,14 +188,15 @@ def processStartTime():
             import re
 
             procStatContent = open('/proc/stat').read()
-            btimeEntry = re.match('(?:.|\n)*btime ([0-9]+)', procStatContent).group(1)
+            btimeEntry = re.match('(?:.|\n)*btime ([0-9]+)',
+                                  procStatContent).group(1)
             bootTimeUNIXSeconds = int(btimeEntry)
 
             selfStatContent = open('/proc/self/stat').read()
             startTimeBootJiffies = int(selfStatContent.split(' ')[21])
 
-            __processStartTime = (  float(bootTimeUNIXSeconds)
-                                  + float(startTimeBootJiffies) / 100.0)
+            __processStartTime = float(bootTimeUNIXSeconds) \
+                + float(startTimeBootJiffies) / 100.0
         except:
             pass
 
@@ -182,6 +207,7 @@ def processStartTime():
 
     return __processStartTime
 
+
 def programName():
     import __main__
     if hasattr(__main__, '__file__'):
@@ -189,7 +215,8 @@ def programName():
     else:
         return '<no script>'
 
-class ProcessInfo (object):
+
+class ProcessInfo(object):
     """
     Instances of this class store information about operating system
     processes.
@@ -197,37 +224,38 @@ class ProcessInfo (object):
     The stored information can describe the current process, a
     different process on the local machine or a remote process.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self,
-                 id            = os.getpid(),
-                 programName   = ('python%d.%d %s'
-                                  % (sys.version_info.major,
-                                     sys.version_info.minor,
-                                     programName())),
-                 arguments     = sys.argv,
-                 startTime     = processStartTime(),
-                 executingUser = None,
-                 rsbVersion    = rsb.version.getVersion()):
-        self.__id            = id
-        self.__programName   = programName
-        self.__arguments     = arguments
-        self.__startTime     = startTime
+                 id=os.getpid(),
+                 programName='python%d.%d %s'
+                 % (sys.version_info.major,
+                    sys.version_info.minor,
+                    programName()),
+                 arguments=copy.copy(sys.argv),
+                 startTime=processStartTime(),
+                 executingUser=None,
+                 rsbVersion=rsb.version.getVersion()):
+        self.__id = id
+        self.__programName = programName
+        self.__arguments = arguments
+        self.__startTime = startTime
         self.__executingUser = executingUser
         if not self.__executingUser:
             try:
                 self.__executingUser = os.getlogin()
             except OSError:
                 pass
-        self.__rsbVersion    = rsbVersion
+        self.__rsbVersion = rsbVersion
 
     def getId(self):
         """
         Returns the numeric id of the process.
 
-        @return: The numeric id of the process.
-        @rtype: int
+        Returns:
+            int:
+                The numeric id of the process.
         """
         return self.__id
 
@@ -237,8 +265,9 @@ class ProcessInfo (object):
         """
         Returns the name of the program being executed in the process.
 
-        @return: The name of the program.
-        @rtype: str
+        Returns:
+            str:
+                The name of the program.
         """
         return self.__programName
 
@@ -249,8 +278,9 @@ class ProcessInfo (object):
         Returns the list of commandline argument the process has been
         started with.
 
-        @return: A list of commandline argument strings
-        @rtype: list
+        Returns:
+            list:
+                A list of commandline argument strings
         """
         return self.__arguments
 
@@ -261,8 +291,9 @@ class ProcessInfo (object):
         Returns the start time of the process in fractional seconds
         since UNIX epoch.
 
-        @return: start time in fractional seconds since UNIX epoch.
-        @rtype: float
+        Returns:
+            float:
+                start time in fractional seconds since UNIX epoch.
         """
         return self.__startTime
 
@@ -273,9 +304,10 @@ class ProcessInfo (object):
         Return the login- or account-name of the user executing the
         process.
 
-        @return: login- or account-name of the user executing the
-                 process or None if not determinable
-        @rtype: str
+        Returns:
+            str:
+                login- or account-name of the user executing the process or
+                None if not determinable
         """
         return self.__executingUser
 
@@ -285,10 +317,11 @@ class ProcessInfo (object):
         """
         Return the version of the RSB implementation used in this process.
 
-        @return: Version string of the form::
+        Returns:
+            str:
+                Version string of the form::
 
                    MAJOR.MINOR.REVISION[-COMMIT]
-        @rtype: str
         """
         return self.__rsbVersion
 
@@ -301,14 +334,15 @@ class ProcessInfo (object):
     def __repr__(self):
         return str(self)
 
+
 def hostId():
     """
     Returns a unique id string for the current host.
 
-    @return: A platform-dependent, string (hopefully) uniquely
-             identifying the current host or C{None} if such an id
-             cannot be obtained.
-    @rtype: str or NoneType
+    Returns:
+        str or NoneType:
+            A platform-dependent, string (hopefully) uniquely identifying the
+            current host or ``None`` if such an id cannot be obtained.
     """
     def maybeRead(filename):
         try:
@@ -317,59 +351,65 @@ def hostId():
         except:
             return None
 
-    return ('linux' in sys.platform and maybeRead('/var/lib/dbus/machine-id')) \
-        or ('linux' in sys.platform and maybeRead('/ect/machine-id'))          \
+    return \
+        ('linux' in sys.platform and maybeRead('/var/lib/dbus/machine-id')) \
+        or ('linux' in sys.platform and maybeRead('/ect/machine-id')) \
         or None
 
+
 def machineType():
     result = platform.machine().lower()
-    if result in [ 'i368', 'i586', 'i686' ]:
+    if result in ['i368', 'i586', 'i686']:
         return 'x86'
-    elif result in [ 'x86_64', 'amd64' ]:
+    elif result in ['x86_64', 'amd64']:
         return 'x86_64'
     else:
         return result
 
+
 def machineVersion():
     if 'linux' in sys.platform:
         import re
 
         try:
             cpuInfo = open('/proc/cpuinfo').read()
-            return re.match('(?:.|\n)*model name\t: ([^\n]+)', cpuInfo).group(1)
+            return re.match('(?:.|\n)*model name\t: ([^\n]+)',
+                            cpuInfo).group(1)
         except:
             return None
 
-class HostInfo (object):
+
+class HostInfo(object):
     """
     Instances of this class store information about a host.
 
     The stored information can describe the local host or a remote
     host.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self,
-                 id              = hostId(),
-                 hostname        = platform.node().split('.')[0],
-                 machineType     = machineType(),
-                 machineVersion  = machineVersion(),
-                 softwareType    = platform.system().lower(),
-                 softwareVersion = platform.release()):
-        self.__id              = id
-        self.__hostname        = hostname
-        self.__machineType     = machineType
-        self.__machineVersion  = machineVersion
-        self.__softwareType    = softwareType
+                 id=hostId(),
+                 hostname=platform.node().split('.')[0],
+                 machineType=machineType(),
+                 machineVersion=machineVersion(),
+                 softwareType=platform.system().lower(),
+                 softwareVersion=platform.release()):
+        self.__id = id
+        self.__hostname = hostname
+        self.__machineType = machineType
+        self.__machineVersion = machineVersion
+        self.__softwareType = softwareType
         self.__softwareVersion = softwareVersion
 
     def getId(self):
         """
         Return the unique id string for the host.
 
-        @return: The platform-dependent, (hopefully) unique id string.
-        @rtype: str or None
+        Returns:
+            str or None:
+                The platform-dependent, (hopefully) unique id string.
         """
         return self.__id
 
@@ -379,8 +419,9 @@ class HostInfo (object):
         """
         Returns the hostname of the host.
 
-        @return: The hostname.
-        @rtype: str
+        Returns:
+            str:
+                The hostname.
         """
         return self.__hostname
 
@@ -390,8 +431,9 @@ class HostInfo (object):
         """
         Return the type of the machine, usually CPU architecture.
 
-        @return: The machine type when known.
-        @rtype: str or NoneType
+        Returns:
+            str or NoneType:
+                The machine type when known.
         """
         return self.__machineType
 
@@ -402,8 +444,9 @@ class HostInfo (object):
         Returns the version of the machine within its type, usually
         the CPU identification string.
 
-        @return: The machine version when known.
-        @rtype: str or NoneType
+        Returns:
+            str or NoneType:
+                The machine version when known.
         """
         return self.__machineVersion
 
@@ -414,8 +457,9 @@ class HostInfo (object):
         Returns the type of the operating system running on the host,
         usually the kernel name.
 
-        @return: The software type when known.
-        @rtype: str or NoneType
+        Returns:
+            str or NoneType:
+                The software type when known.
         """
         return self.__softwareType
 
@@ -426,8 +470,9 @@ class HostInfo (object):
         Returns the version of the operating system within its type,
         usually the kernel version string.
 
-        @return: The software version when known.
-        @rtype: str or NoneType
+        Returns:
+            str or NoneType:
+                The software version when known.
         """
         return self.__softwareVersion
 
@@ -444,19 +489,22 @@ class HostInfo (object):
 
 # IntrospectionSender
 
-baseScope         = rsb.Scope('/__rsb/introspection/')
-participantsScope = baseScope.concat(rsb.Scope('/participants/'))
-hostsScope        = baseScope.concat(rsb.Scope('/hosts/'))
+BASE_SCOPE = rsb.Scope('/__rsb/introspection/')
+PARTICIPANTS_SCOPE = BASE_SCOPE.concat(rsb.Scope('/participants/'))
+HOSTS_SCOPE = BASE_SCOPE.concat(rsb.Scope('/hosts/'))
 
-def participantScope(participantId, baseScope = participantsScope):
+
+def participantScope(participantId, baseScope=PARTICIPANTS_SCOPE):
     return baseScope.concat(rsb.Scope('/' + str(participantId)))
 
-def processScope(hostId, processId, baseScope = hostsScope):
+
+def processScope(hostId, processId, baseScope=HOSTS_SCOPE):
     return (baseScope
             .concat(rsb.Scope('/' + hostId))
             .concat(rsb.Scope('/' + processId)))
 
-class IntrospectionSender (object):
+
+class IntrospectionSender(object):
     """
     Instances of this class (usually zero or one per process) send
     information about participants in the current process, the current
@@ -464,10 +512,10 @@ class IntrospectionSender (object):
     information.
 
     Instances need to be notified of created and destroyed
-    participants via calls of the L{addParticipant} and
-    L{removeParticipant} methods.
+    participants via calls of the :obj:`addParticipant` and
+    :obj:`removeParticipant` methods.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self):
@@ -476,60 +524,67 @@ class IntrospectionSender (object):
         self.__participants = []
 
         self.__process = ProcessInfo()
-        self.__host    = HostInfo()
+        self.__host = HostInfo()
+
+        self.__informer = rsb.createInformer(PARTICIPANTS_SCOPE)
+        self.__listener = rsb.createListener(PARTICIPANTS_SCOPE)
 
-        self.__informer = rsb.createInformer(participantsScope)
-        self.__listener = rsb.createListener(participantsScope)
         def handle(event):
-            if not event.method in [ 'REQUEST', 'SURVEY' ]: # TODO use filter when we get conjunction filter
+            # TODO use filter when we get conjunction filter
+            if event.method not in ['REQUEST', 'SURVEY']:
                 return
 
-            id          = None
+            participantId = None
             participant = None
-            if len(event.scope.components) > len(participantsScope.components):
+            if len(event.scope.components) > \
+                    len(PARTICIPANTS_SCOPE.components):
                 try:
-                    id = uuid.UUID(event.scope.components[-1])
-                    if not id is None:
-                        for p in self.__participants: # TODO there has to be a better way
-                            if p.id == id:
+                    participantId = uuid.UUID(event.scope.components[-1])
+                    if participantId is not None:
+                        # TODO there has to be a better way
+                        for p in self.__participants:
+                            if p.id == participantId:
                                 participant = p
                             break
                 except Exception, e:
-                    self.__logger.warn('Query event %s does not properly address a participant: %s',
+                    self.__logger.warn('Query event %s does not '
+                                       'properly address a participant: %s',
                                        event, e)
 
             def process(thunk):
-                if not participant is None and event.method == 'REQUEST':
-                    thunk(query = event, participant = participant)
+                if participant is not None and event.method == 'REQUEST':
+                    thunk(query=event, participant=participant)
                 elif participant is None and event.method == 'SURVEY':
-                    map(lambda p: thunk(query = event, participant = p),
-                        self.__participants)
+                    for p in self.__participants:
+                        thunk(query=event, participant=p)
                 else:
-                    self.__logger.warn('Query event %s not understood' % event)
+                    self.__logger.warn('Query event %s not understood', event)
 
             if event.data is None:
                 process(self.sendHello)
             elif event.data == 'ping':
                 process(self.sendPong)
             else:
-                self.__logger.warn('Query event %s not understood' % event)
+                self.__logger.warn('Query event %s not understood', event)
 
         self.__listener.addHandler(handle)
 
-        self.__server = rsb.createServer(processScope(self.__host.id or self.__host.hostname,
-                                                      str(self.__process.id)))
+        self.__server = rsb.createServer(
+            processScope(self.__host.id or self.__host.hostname,
+                         str(self.__process.id)))
+
         def echo(request):
-            reply = rsb.Event(scope = request.scope,
-                              data = request.data,
-                              type = type(request.data))
+            reply = rsb.Event(scope=request.scope,
+                              data=request.data,
+                              type=type(request.data))
             reply.metaData.setUserTime('request.send',
                                        request.metaData.sendTime)
             reply.metaData.setUserTime('request.receive',
                                        request.metaData.receiveTime)
             return reply
         self.__server.addMethod('echo', echo,
-                                requestType = rsb.Event,
-                                replyType   = rsb.Event)
+                                requestType=rsb.Event,
+                                replyType=rsb.Event)
 
     def deactivate(self):
         self.__listener.deactivate()
@@ -546,7 +601,7 @@ class IntrospectionSender (object):
 
     host = property(getHost)
 
-    def addParticipant(self, participant, parent = None):
+    def addParticipant(self, participant, parent=None):
         parentId = None
         if parent:
             parentId = parent.id
@@ -559,11 +614,13 @@ class IntrospectionSender (object):
                 result.append(c.lower())
             return ''.join(result)
 
-        info = ParticipantInfo(kind     = camelCaseToDashSeperated(type(participant).__name__ ),
-                               id       = participant.id,
-                               parentId = parentId,
-                               scope    = participant.scope,
-                               type     = object) # TODO
+        info = ParticipantInfo(
+            kind=camelCaseToDashSeperated(type(participant).__name__),
+            id=participant.id,
+            parentId=parentId,
+            scope=participant.scope,
+            type=object,  # TODO
+            transportURLs=participant.transportURLs)
 
         self.__participants.append(info)
 
@@ -576,19 +633,21 @@ class IntrospectionSender (object):
                 removed = p
                 break
 
-        if not removed is None:
+        if removed is not None:
             self.__participants.remove(removed)
             self.sendBye(removed)
 
         return bool(self.__participants)
 
-    def sendHello(self, participant, query = None):
+    def sendHello(self, participant, query=None):
         hello = Hello()
-        hello.kind  = participant.kind
-        hello.id    = participant.id.get_bytes()
+        hello.kind = participant.kind
+        hello.id = participant.id.get_bytes()
         hello.scope = participant.scope.toString()
         if participant.parentId:
             hello.parent = participant.parentId.get_bytes()
+        for url in participant.transportURLs:
+            hello.transport.append(url)
 
         host = hello.host
         if self.host.id is None:
@@ -597,25 +656,26 @@ class IntrospectionSender (object):
             host.id = self.host.id
         host.hostname = self.host.hostname
         host.machine_type = self.host.machineType
-        if not self.host.machineVersion is None:
+        if self.host.machineVersion is not None:
             host.machine_version = self.host.machineVersion
         host.software_type = self.host.softwareType
         host.software_version = self.host.softwareVersion
 
         process = hello.process
-        process.id             = str(self.process.id)
-        process.program_name   = self.process.programName
-        map(process.commandline_arguments.append, self.process.arguments)
-        process.start_time     = int(self.process.startTime * 1000000.0)
+        process.id = str(self.process.id)
+        process.program_name = self.process.programName
+        for argument in self.process.arguments:
+            process.commandline_arguments.append(argument)
+        process.start_time = int(self.process.startTime * 1000000.0)
         if self.process.executingUser:
             process.executing_user = self.process.executingUser
-        process.rsb_version    = self.process.rsbVersion
+        process.rsb_version = self.process.rsbVersion
         if _displayName:
             process.display_name = _displayName
         scope = participantScope(participant.id, self.__informer.scope)
-        helloEvent = rsb.Event(scope = scope,
-                               data  = hello,
-                               type  = type(hello))
+        helloEvent = rsb.Event(scope=scope,
+                               data=hello,
+                               type=type(hello))
         if query:
             helloEvent.addCause(query.id)
         self.__informer.publishEvent(helloEvent)
@@ -625,50 +685,52 @@ class IntrospectionSender (object):
         bye.id = participant.id.get_bytes()
 
         scope = participantScope(participant.id, self.__informer.scope)
-        byeEvent = rsb.Event(scope = scope,
-                             data  = bye,
-                             type  = type(bye))
+        byeEvent = rsb.Event(scope=scope,
+                             data=bye,
+                             type=type(bye))
         self.__informer.publishEvent(byeEvent)
 
-    def sendPong(self, participant, query = None):
+    def sendPong(self, participant, query=None):
         scope = participantScope(participant.id, self.__informer.scope)
-        pongEvent = rsb.Event(scope = scope,
-                              data  = 'pong',
-                              type  = str)
+        pongEvent = rsb.Event(scope=scope,
+                              data='pong',
+                              type=str)
         if query:
             pongEvent.addCause(query.id)
         self.__informer.publishEvent(pongEvent)
 
 __sender = None
 
-def handleParticipantCreation(participant, parent = None):
+
+def handleParticipantCreation(participant, parent=None):
     """
     This function is intended to be connected to
-    L{rsb.participantCreationHook} and calls
-    L{IntrospectionSender.addParticipant} when appropriate, first
-    creating the L{IntrospectionSender} instance, if necessary.
+    :obj:`rsb.participantCreationHook` and calls
+    :obj:`IntrospectionSender.addParticipant` when appropriate, first
+    creating the :obj:`IntrospectionSender` instance, if necessary.
     """
     global __sender
 
-    if participant.scope.isSubScopeOf(baseScope) \
+    if participant.scope.isSubScopeOf(BASE_SCOPE) \
        or not participant.config.introspection:
         return
 
     if __sender is None:
         __sender = IntrospectionSender()
-    __sender.addParticipant(participant, parent = parent)
+    __sender.addParticipant(participant, parent=parent)
+
 
 def handleParticipantDestruction(participant):
     """
     This function is intended to be connected to
-    L{rsb.participantDestructionHook} and calls
-    L{IntrospectionSender.removeParticipant} when appropriate,
-    potentially deleting the L{IntrospectionSender} instance
+    :obj:`rsb.participantDestructionHook` and calls
+    :obj:`IntrospectionSender.removeParticipant` when appropriate,
+    potentially deleting the :obj:`IntrospectionSender` instance
     afterwards.
     """
     global __sender
 
-    if participant.scope.isSubScopeOf(baseScope) \
+    if participant.scope.isSubScopeOf(BASE_SCOPE) \
        or not participant.config.introspection:
         return
 
@@ -676,22 +738,24 @@ def handleParticipantDestruction(participant):
         __sender.deactivate()
         __sender = None
 
+
 def initialize(displayName=None):
     """
     Initializes the introspection module. Clients need to ensure that this
     method is called only once.
 
-    @param displayName: a user-defined process name to use in the introspection
-    @type displayName: str or NoneType if not set
+    Args:
+        displayName (str or NoneType if not set, optional):
+            a user-defined process name to use in the introspection
     """
     global _displayName
 
     _displayName = displayName
 
     # Register converters for introspection messages
-    for clazz in [ Hello, Bye ]:
-        converter = rsb.converter.ProtocolBufferConverter(messageClass = clazz)
-        rsb.converter.registerGlobalConverter(converter, replaceExisting = True)
+    for clazz in [Hello, Bye]:
+        converter = rsb.converter.ProtocolBufferConverter(messageClass=clazz)
+        rsb.converter.registerGlobalConverter(converter, replaceExisting=True)
 
     rsb.participantCreationHook.addHandler(handleParticipantCreation)
     rsb.participantDestructionHook.addHandler(handleParticipantDestruction)
