@@ -27,8 +27,8 @@
 This module contains different transport implementations for RSB and their
 common base classes and utility functions.
 
-@author: jmoringe
-@author: jwienke
+.. codeauthor:: jmoringe
+.. codeauthor:: jwienke
 """
 
 import abc
@@ -38,30 +38,32 @@ import threading
 from rsb.util import getLoggerByClass
 import logging
 
+
 class Connector(object):
     """
     Superclass for transport-specific connector classes.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
-    def __init__(self, wireType = None, **kwargs):
+    def __init__(self, wireType=None, **kwargs):
         """
         Creates a new connector with a serialization type wireType.
 
-        @param wireType: the type of serialized data used by this
-                         connector.
-        @type wireType: type
+        Args:
+            wireType (types.TypeType):
+                the type of serialized data used by this connector.
         """
         self.__logger = getLoggerByClass(self.__class__)
 
         self.__wireType = None
-        self.__scope    = None
+        self.__scope = None
 
-        if wireType == None:
+        if wireType is None:
             raise ValueError("Wire type must be a type object, None given")
 
-        self.__logger.debug("Using specified converter map for wire-type %s", wireType)
+        self.__logger.debug("Using specified converter map for wire-type %s",
+                            wireType)
         self.__wireType = wireType
 
         # fails if still some arguments are left over
@@ -71,7 +73,8 @@ class Connector(object):
         """
         Returns the serialization type used for this connector.
 
-        @return: python serialization type
+        Returns:
+            python serialization type
         """
         return self.__wireType
 
@@ -83,10 +86,11 @@ class Connector(object):
     def setScope(self, newValue):
         """
         Sets the scope this connector will receive events from to
-        B{newValue}. Called before #activate.
+        ``newValue``. Called before #activate.
 
-        @param newValue: scope of the connector
-        @type newValue: rsb.Scope
+        Args:
+            newValue (rsb.Scope):
+                scope of the connector
         """
         self.__scope = newValue
 
@@ -101,12 +105,13 @@ class Connector(object):
     def setQualityOfServiceSpec(self, qos):
         raise NotImplementedError()
 
+
 class InConnector(Connector):
     """
     Superclass for in-direction (that is, dealing with incoming
     events) connector implementations.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def filterNotify(self, filter, action):
@@ -117,48 +122,54 @@ class InConnector(Connector):
         Sets the action used by the connector to notify about incoming
         events. The call to this method must be thread-safe.
 
-        @param action: action called if a new message is received from
-        the connector. Must accept an L{Event} as parameter.
+        Args:
+            action:
+                action called if a new message is received from the connector.
+                Must accept an :obj:`Event` as parameter.
         """
         pass
 
+
 class OutConnector(Connector):
     """
     Superclass for out-direction (that is, dealing with outgoing
     events) connector implementations.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def handle(self, event):
         """
-        Sends B{event} and adapts its meta data instance with the
+        Sends ``event`` and adapts its meta data instance with the
         actual send time.
 
-        @param event: event to send
+        Args:
+            event:
+                event to send
         """
         raise NotImplementedError()
 
-class ConverterSelectingConnector (object):
+
+class ConverterSelectingConnector(object):
     """
     This class is intended to be used a superclass (or rather mixin
     class) for connector classes which have to store a map of
     converters and select converters for (de)serialization.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self, converters, **kwargs):
         """
         Creates a new connector that uses the converters in
-        B{converters} to deserialize notification and/or serialize
+        ``converters`` to deserialize notification and/or serialize
         events.
 
-        @param converters: The converter selection strategy that
-                           should be used by the connector. If
-                           C{None}, the global map of converters for
-                           the wire-type of the connector is used.
-        @type converters: rsb.converter.ConverterSelectionStrategy
+        Args:
+            converters (rsb.converter.ConverterSelectionStrategy):
+                The converter selection strategy that should be used by the
+                connector. If ``None``, the global map of converters for the
+                wire-type of the connector is used.
         """
         self.__converterMap = converters
 
@@ -169,24 +180,36 @@ class ConverterSelectingConnector (object):
         Returns a converter that can convert the supplied data to the
         wire-type.
 
-        @param dataType: the type of the object for which a suitable
-                         converter should returned.
-        @return: converter
-        @raise KeyError: no converter is available for the supplied
-                         data.
+        Args:
+            dataType:
+                the type of the object for which a suitable converter should
+                returned.
+
+        Returns:
+            converter
+
+        Raises:
+            KeyError:
+                no converter is available for the supplied data.
         """
         return self.__converterMap.getConverterForDataType(dataType)
 
     def getConverterForWireSchema(self, wireSchema):
         """
-        Returns a suitable converter for the B{wireSchema}.
+        Returns a suitable converter for the ``wireSchema``.
+
+        Args:
+            wireSchema (str):
+                the wire-schema to or from which the returned converter should
+                convert
+
+        Returns:
+            converter
+
+        Raises:
+            KeyError:
+                no converter is available for the specified wire-schema.
 
-        @param wireSchema: the wire-schema to or from which the
-                           returned converter should convert
-        @type wireSchema: str
-        @return: converter
-        @raise KeyError: no converter is available for the specified
-                         wire-schema.
         """
         return self.__converterMap.getConverterForWireSchema(wireSchema)
 
@@ -195,10 +218,11 @@ class ConverterSelectingConnector (object):
 
     converterMap = property(getConverterMap)
 
+
 class TransportFactory(object):
     """
-    Interface for factories which are able to create L{Connector} instances for
-    a certain transport.
+    Interface for factories which are able to create :obj:`Connector` instances
+    for a certain transport.
     """
 
     __metaclass__ = abc.ABCMeta
@@ -208,38 +232,43 @@ class TransportFactory(object):
         """
         Returns the name representing this transport.
 
-        @return: name of the transport, non-empty
-        @rtype: str
+        Returns:
+            str:
+                name of the transport, non-empty
         """
         pass
 
     @abc.abstractmethod
     def createInPushConnector(self, converters, options):
         """
-        Creates a new instance of an L{InConnector} for the represented
+        Creates a new instance of an :obj:`InConnector` for the represented
         transport.
 
-        @param converters: the converters to use for this type
-        @type converters: ConverterSelectionStrategy
-        @param options: options for the new connector
-        @type options: dict of str
-        @return: the new connector instance
-        @rtype: InConnector
+        Args:
+            converters (ConverterSelectionStrategy):
+                the converters to use for this type options(dict of str):
+                options for the new connector
+
+        Returns:
+            rsb.transport.InConnector:
+                the new connector instance
         """
         pass
 
     @abc.abstractmethod
     def createOutConnector(self, converters, options):
         """
-        Creates a new instance of an L{OutConnector} for the represented
+        Creates a new instance of an :obj:`OutConnector` for the represented
         transport.
 
-        @param converters: the converters to use for this type
-        @type converters: ConverterSelectionStrategy
-        @param options: options for the new connector
-        @type options: dict of str
-        @return: the new connector instance
-        @rtype: OutConnector
+        Args:
+            converters (ConverterSelectionStrategy):
+                the converters to use for this type options(dict of str):
+                options for the new connector
+
+        Returns:
+            rsb.transport.OutConnector:
+                the new connector instance
         """
         pass
 
@@ -247,14 +276,20 @@ class TransportFactory(object):
 __factoriesByName = {}
 __factoryLock = threading.Lock()
 
+
 def registerTransport(factory):
     """
     Registers a new transport.
 
-    @param factory: the factory for the transport
-    @type factory: TransportFactory
-    @raise ValueError: there is already a transport registered with this name
-                       or the given factory argument is invalid
+    Args:
+        factory (rsb.transport.TransportFactory):
+            the factory for the transport
+
+    Raises:
+        ValueError:
+            there is already a transport registered with this name or the given
+            factory argument is invalid
+
     """
 
     if factory is None:
@@ -266,16 +301,23 @@ def registerTransport(factory):
                     name=factory.getName()))
         __factoriesByName[factory.getName()] = factory
 
+
 def getTransportFactory(name):
     """
-    Returns a l{TransportFactory} instance for the transport with the given
+    Returns a ``TransportFactory`` instance for the transport with the given
     name.
 
-    @param name: name of the transport
-    @type name: str
-    @return: the l{TransportFactory} instance
-    @rtype: TransportFactory
-    @raise KeyError: there is not transport with the given name
+    Args:
+        name (str):
+            name of the transport
+
+    Returns:
+        rsb.transport.TransportFactory:
+            the ``TransportFactory`` instance
+
+    Raises:
+        KeyError:
+            there is not transport with the given name
     """
     with __factoryLock:
         return __factoriesByName[name]
