@@ -27,17 +27,21 @@ This package contains a highly efficient in-process transport implementation
 which allows participants inside one python process to communicate without
 serialization overhead.
 
-@author: jwienke
+.. codeauthor:: jwienke
 """
 
+import os
+import platform
 from threading import RLock
+
 from rsb import transport
 
+
 class Bus(object):
     """
     Singleton-like representation of the local bus.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self):
@@ -48,7 +52,9 @@ class Bus(object):
         """
         Adds a sink for events pushed to the Bus.
 
-        @param sink: the sink to add
+        Args:
+            sink:
+                the sink to add
         """
         with self.__mutex:
             # ensure that there is a list of sinks for the given scope
@@ -60,7 +66,9 @@ class Bus(object):
         """
         Removes a sink to not be notified anymore.
 
-        @param sink: sink to remove
+        Args:
+            sink:
+                sink to remove
         """
         with self.__mutex:
             # return immediately if there is no such scope known for sinks
@@ -72,8 +80,9 @@ class Bus(object):
         """
         Dispatches the provided event to all sinks of the appropriate scope.
 
-        @param event: event to dispatch
-        @type event: rsb.Event
+        Args:
+            event (rsb.Event):
+                event to dispatch
         """
 
         with self.__mutex:
@@ -83,16 +92,23 @@ class Bus(object):
                     for sink in sinkList:
                         sink.handle(event)
 
+    def getTransportURL(self):
+        hostname = platform.node().split('.')[0]
+        pid = os.getpid()
+        return 'inprocess://' + hostname + ':' + str(pid)
+
 globalBus = Bus()
 
+
 class OutConnector(transport.OutConnector):
     """
     In-process OutConnector.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, bus=globalBus, converters=None, options=None, **kwargs):
+        # pylint: disable=unused-argument
         transport.OutConnector.__init__(self, wireType=object, **kwargs)
         self.__bus = bus
 
@@ -109,14 +125,19 @@ class OutConnector(transport.OutConnector):
     def setQualityOfServiceSpec(self, qos):
         pass
 
+    def getTransportURL(self):
+        return self.__bus.getTransportURL()
+
+
 class InConnector(transport.InConnector):
     """
     InConnector for the local transport.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, bus=globalBus, converters=None, options=None, **kwargs):
+        # pylint: disable=unused-argument
         transport.InConnector.__init__(self, wireType=object, **kwargs)
         self.__bus = bus
         self.__scope = None
@@ -151,11 +172,15 @@ class InConnector(transport.InConnector):
         if action is not None:
             action(event)
 
+    def getTransportURL(self):
+        return self.__bus.getTransportURL()
+
+
 class TransportFactory(transport.TransportFactory):
     """
-    L{TransportFactory} implementation for the local transport.
+    :obj:`TransportFactory` implementation for the local transport.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def getName(self):
@@ -167,6 +192,7 @@ class TransportFactory(transport.TransportFactory):
     def createOutConnector(self, converters, options):
         return OutConnector(converters=converters, options=options)
 
+
 def initialize():
     try:
         transport.registerTransport(TransportFactory())
