@@ -1,7 +1,7 @@
 # ============================================================
 #
 # Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
-# Copyright (C) 2011, 2012 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
+# Copyright (C) 2011, 2012, 2015 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
 #
 # This file may be licensed under the terms of the
 # GNU Lesser General Public License Version 3 (the ``LGPL''),
@@ -27,8 +27,8 @@
 This package contains a transport implementation based on the spread toolkit
 which uses a multicased-based daemon network.
 
-@author: jmoringe
-@author: jwienke
+.. codeauthor:: jmoringe
+.. codeauthor:: jwienke
 """
 
 import threading
@@ -52,34 +52,40 @@ from google.protobuf.message import DecodeError
 
 import rsb.transport.conversion as conversion
 
+
 def makeKey(notification):
-    key = notification.event_id.sender_id + '%08x' % notification.event_id.sequence_number
+    key = notification.event_id.sender_id + '%08x' \
+        % notification.event_id.sequence_number
     return key
 
+
 class Assembly(object):
     """
     A class that maintains a collection of fragments of one fragmented
     notification and assembles them if all fragments are received.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, fragment):
         self.__requiredParts = fragment.num_data_parts
         assert(self.__requiredParts > 1)
-        self.__id    = makeKey(fragment.notification)
-        self.__parts = {fragment.data_part : fragment}
+        self.__id = makeKey(fragment.notification)
+        self.__parts = {fragment.data_part: fragment}
 
     def add(self, fragment):
         key = makeKey(fragment.notification)
         assert(key == self.__id)
         if fragment.data_part in self.__parts:
-            raise ValueError("Received part %u for notification with id %s again." % (fragment.data_part, key))
+            raise ValueError(
+                "Received part %u for notification with id %s again."
+                % (fragment.data_part, key))
 
         self.__parts[fragment.data_part] = fragment
 
         if len(self.__parts) == self.__requiredParts:
-            return self.__parts[0].notification, self.__join(), self.__parts[0].notification.wire_schema
+            return (self.__parts[0].notification, self.__join(),
+                    self.__parts[0].notification.wire_schema)
         else:
             return None
 
@@ -91,12 +97,13 @@ class Assembly(object):
             finalData += bytearray(self.__parts[key].notification.data)
         return finalData
 
+
 class AssemblyPool(object):
     """
     Maintains the parallel joining of notification fragments that are
     received in an interleaved fashion.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self):
@@ -105,22 +112,24 @@ class AssemblyPool(object):
     def add(self, fragment):
         notification = fragment.notification
         if fragment.num_data_parts == 1:
-            return notification, bytearray(notification.data), notification.wire_schema
+            return (notification, bytearray(notification.data),
+                    notification.wire_schema)
         key = makeKey(notification)
-        if not key in self.__assemblies:
+        if key not in self.__assemblies:
             self.__assemblies[key] = Assembly(fragment)
             return None
         else:
             result = self.__assemblies[key].add(fragment)
-            if result != None:
+            if result is not None:
                 del self.__assemblies[key]
                 return result
 
+
 class SpreadConnection(object):
     """
     A wrapper around a spread mailbox for some convenience.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, daemonName, spreadModule=spread):
@@ -148,6 +157,13 @@ class SpreadConnection(object):
             raise ValueError("Not activated")
         return getattr(self.__mailbox, name)
 
+    def getHost(self):
+        name = self.__daemonName.split('@')
+        return name[1] if '@' in name else 'localhost'
+
+    def getPort(self):
+        return int(self.__daemonName.split('@')[0])
+
 
 class RefCountingSpreadConnection(SpreadConnection):
 
@@ -170,20 +186,25 @@ class RefCountingSpreadConnection(SpreadConnection):
             if self.__counter == 0:
                 SpreadConnection.deactivate(self)
 
+
 class SpreadReceiverTask(object):
     """
     Thread used to receive messages from a spread connection.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self, mailbox, observerAction, converterMap):
         """
         Constructor.
 
-        @param mailbox: spread mailbox to receive from
-        @param observerAction: callable to execute if a new event is received
-        @param converterMap: converters for data
+        Args:
+            mailbox:
+                spread mailbox to receive from
+            observerAction:
+                callable to execute if a new event is received
+            converterMap:
+                converters for data
         """
 
         self.__logger = rsb.util.getLoggerByClass(self.__class__)
@@ -242,24 +263,33 @@ class SpreadReceiverTask(object):
                         continue
 
                     if self.__logger.isEnabledFor(logging.DEBUG):
-                        self.__logger.debug("Received notification fragment from bus (%s/%s), data length: %s",
-                                            fragment.data_part,
-                                            fragment.num_data_parts,
-                                            len(fragment.notification.data))
+                        self.__logger.debug(
+                            "Received notification fragment "
+                            "from bus (%s/%s), data length: %s",
+                            fragment.data_part,
+                            fragment.num_data_parts,
+                            len(fragment.notification.data))
 
                     assembled = self.__assemblyPool.add(fragment)
                     if assembled:
                         notification, joinedData, wireSchema = assembled
                         # Create event from (potentially assembled)
                         # notification(s)
-                        converter = self.__converterMap.getConverterForWireSchema(wireSchema)
+                        converter = \
+                            self.__converterMap.getConverterForWireSchema(
+                                wireSchema)
                         try:
-                            event = conversion.notificationToEvent(notification, joinedData, wireSchema, converter)
+                            event = conversion.notificationToEvent(
+                                notification, joinedData, wireSchema,
+                                converter)
                         except Exception:
-                            self.__logger.exception("Unable to decode event. Ignoring and continuing.")
+                            self.__logger.exception(
+                                "Unable to decode event. "
+                                "Ignoring and continuing.")
                             continue
 
-                        self.__logger.debug("Sending event to dispatch task: %s", event)
+                        self.__logger.debug(
+                            "Sending event to dispatch task: %s", event)
 
                         with self.__observerActionLock:
                             if self.__observerAction:
@@ -267,7 +297,9 @@ class SpreadReceiverTask(object):
 
                 # Process membership message
                 elif isinstance(message, spread.MembershipMsgType):
-                    self.__logger.info("Received membership message for group `%s'", message.group)
+                    self.__logger.info(
+                        "Received membership message for group `%s'",
+                        message.group)
 
             except Exception, e:
                 self.__logger.exception("Error processing new event")
@@ -288,6 +320,7 @@ class SpreadReceiverTask(object):
         with self.__observerActionLock:
             self.__observerAction = action
 
+
 class Connector(rsb.transport.Connector,
                 rsb.transport.ConverterSelectingConnector):
     """
@@ -295,13 +328,13 @@ class Connector(rsb.transport.Connector,
     the direction-independent aspects like the Spread connection and
     (de)activation.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     MAX_MSG_LENGTH = 100000
 
     def __init__(self, connection, **kwargs):
-        super(Connector, self).__init__(wireType = bytearray, **kwargs)
+        super(Connector, self).__init__(wireType=bytearray, **kwargs)
 
         self.__logger = rsb.util.getLoggerByClass(self.__class__)
         self.__connection = connection
@@ -331,20 +364,22 @@ class Connector(rsb.transport.Connector,
 
     def activate(self):
         if self.__active:
-            raise RuntimeError, 'Trying to activate active Connector'
+            raise RuntimeError('Trying to activate active Connector')
 
-        self.__logger.info("Activating spread connector with connection %s", self.__connection)
+        self.__logger.info("Activating spread connector with connection %s",
+                           self.__connection)
 
         try:
             self.__connection.activate()
         except Exception, e:
-            raise RuntimeError, 'could not connect SpreadConnection "%s": %s' % (self._connection, e)
+            raise RuntimeError('Could not connect SpreadConnection "%s": %s' %
+                               (self.__connection, e))
 
         self.__active = True
 
     def deactivate(self):
         if not self.__active:
-            raise RuntimeError, 'Trying to deactivate inactive Connector'
+            raise RuntimeError('Trying to deactivate inactive Connector')
 
         self.__logger.info("Deactivating spread connector")
 
@@ -354,28 +389,42 @@ class Connector(rsb.transport.Connector,
 
         self.__logger.debug("SpreadConnector deactivated")
 
-    def _groupName(self, scope):
+    @staticmethod
+    def _groupName(scope):
         hashSum = hashlib.md5()
         hashSum.update(scope.toString())
         return hashSum.hexdigest()[:-1]
 
     def setQualityOfServiceSpec(self, qos):
         self.__logger.debug("Adapting service type for QoS %s", qos)
-        if qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.UNRELIABLE and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.UNORDERED:
+        if qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.UNRELIABLE \
+           and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.UNORDERED:
             self.__msgType = spread.UNRELIABLE_MESS
-            self.__logger.debug("Chosen service type is UNRELIABLE_MESS,  value = %s", self.__msgType)
-        elif qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.UNRELIABLE and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.ORDERED:
+            self.__logger.debug("Chosen service type is UNRELIABLE_MESS,  value = %s",
+                                self.__msgType)
+        elif qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.UNRELIABLE \
+             and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.ORDERED:
             self.__msgType = spread.FIFO_MESS
-            self.__logger.debug("Chosen service type is FIFO_MESS,  value = %s", self.__msgType)
-        elif qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.RELIABLE and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.UNORDERED:
+            self.__logger.debug("Chosen service type is FIFO_MESS,  value = %s",
+                                self.__msgType)
+        elif qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.RELIABLE \
+             and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.UNORDERED:
             self.__msgType = spread.RELIABLE_MESS
-            self.__logger.debug("Chosen service type is RELIABLE_MESS,  value = %s", self.__msgType)
-        elif qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.RELIABLE and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.ORDERED:
+            self.__logger.debug("Chosen service type is RELIABLE_MESS,  value = %s",
+                                self.__msgType)
+        elif qos.getReliability() == rsb.QualityOfServiceSpec.Reliability.RELIABLE \
+             and qos.getOrdering() == rsb.QualityOfServiceSpec.Ordering.ORDERED:
             self.__msgType = spread.FIFO_MESS
-            self.__logger.debug("Chosen service type is FIFO_MESS,  value = %s", self.__msgType)
+            self.__logger.debug("Chosen service type is FIFO_MESS,  value = %s",
+                                self.__msgType)
         else:
             assert(False)
 
+    def getTransportURL(self):
+        return 'spread://' \
+            + self.__connection.getHost()  \
+            + ':' + str(self.__connection.getPort())
+
 class InConnector(Connector,
                   rsb.transport.InConnector):
     def __init__(self, **kwargs):
@@ -415,15 +464,19 @@ class InConnector(Connector,
         super(InConnector, self).deactivate()
 
     def filterNotify(self, theFilter, action):
-        self.__logger.debug("Ignoring filter %s with action %s", theFilter, action)
+        self.__logger.debug("Ignoring filter %s with action %s",
+                            theFilter, action)
 
     def setObserverAction(self, observerAction):
         self.__observerAction = observerAction
-        if self.__receiveTask != None:
-            self.__logger.debug("Passing observer to receive task")
+        if self.__receiveTask is not None:
+            self.__logger.debug("Passing observer %s to receive task",
+                                observerAction)
             self.__receiveTask.setObserverAction(observerAction)
         else:
-            self.__logger.warn("Ignoring observer action %s because there is no dispatch task", observerAction)
+            self.__logger.debug("Storing observer %s until activation",
+                                observerAction)
+
 
 class OutConnector(Connector,
                    rsb.transport.OutConnector):
@@ -442,31 +495,39 @@ class OutConnector(Connector,
         # Create one or more notification fragments for the event
         event.getMetaData().setSendTime()
         converter = self.getConverterForDataType(event.type)
-        fragments = conversion.eventToNotifications(event, converter, self.MAX_MSG_LENGTH)
+        fragments = conversion.eventToNotifications(
+            event, converter, self.MAX_MSG_LENGTH)
 
         # Send fragments
         self.__logger.debug("Sending %u fragments", len(fragments))
         for (i, fragment) in enumerate(fragments):
             serialized = fragment.SerializeToString()
-            self.__logger.debug("Sending fragment %u of length %u", i + 1, len(serialized))
+            self.__logger.debug("Sending fragment %u of length %u",
+                                i + 1, len(serialized))
 
             # TODO respect QoS
-            scopes     = event.scope.superScopes(True)
-            groupNames = map(self._groupName, scopes)
-            self.__logger.debug("Sending to scopes %s which are groupNames %s", scopes, groupNames)
+            scopes = event.scope.superScopes(True)
+            groupNames = [self._groupName(scope) for scope in scopes]
+            self.__logger.debug("Sending to scopes %s which are groupNames %s",
+                                scopes, groupNames)
 
-            sent = self.connection.multigroup_multicast(self._msgType, tuple(groupNames), serialized)
+            sent = self.connection.multigroup_multicast(self._msgType,
+                                                        tuple(groupNames),
+                                                        serialized)
             if (sent > 0):
-                self.__logger.debug("Message sent successfully (bytes = %i)", sent)
+                self.__logger.debug("Message sent successfully (bytes = %i)",
+                                    sent)
             else:
                 # TODO(jmoringe): propagate error
-                self.__logger.warning("Error sending message, status code = %s", sent)
+                self.__logger.warning(
+                    "Error sending message, status code = %s", sent)
+
 
 class TransportFactory(rsb.transport.TransportFactory):
     """
-    L{TransportFactory} implementation for the spread transport.
+    :obj:`TransportFactory` implementation for the spread transport.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def __init__(self):
@@ -476,7 +537,8 @@ class TransportFactory(rsb.transport.TransportFactory):
     def getName(self):
         return "spread"
 
-    def __createDaemonName(self, options):
+    @staticmethod
+    def __createDaemonName(options):
 
         host = options.get('host', None)
         port = options.get('port', '4803')
@@ -500,6 +562,7 @@ class TransportFactory(rsb.transport.TransportFactory):
         return OutConnector(connection=self.__getSharedConnection(
             self.__createDaemonName(options)), converters=converters)
 
+
 def initialize():
     try:
         rsb.transport.registerTransport(TransportFactory())
