@@ -1,6 +1,6 @@
 # ============================================================
 #
-# Copyright (C) 2011, 2012 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
+# Copyright (C) 2011, 2012, 2015 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
 #
 # This file may be licensed under the terms of the
 # GNU Lesser General Public License Version 3 (the ``LGPL''),
@@ -26,12 +26,12 @@
 This package contains a transport implementation that uses multiple
 point-to-point socket connections to simulate a bus.
 
-@author: jmoringe
+.. codeauthor:: jmoringe
 """
 
 import copy
 import socket
-import threading;
+import threading
 
 import rsb.util
 import rsb.transport
@@ -41,42 +41,52 @@ from rsb.protocol.EventId_pb2 import EventId
 from rsb.protocol.EventMetaData_pb2 import UserInfo, UserTime
 from rsb.protocol.Notification_pb2 import Notification
 
-class BusConnection (rsb.eventprocessing.BroadcastProcessor):
+
+class BusConnection(rsb.eventprocessing.BroadcastProcessor):
     """
     Instances of this class implement connections to a socket-based
     bus.
 
     The basic operations provided by this class are receiving an event
-    by calling L{receiveNotification} and submitting an event to the bus by
-    calling L{sendNotification}.
+    by calling :obj:`receiveNotification` and submitting an event to the bus by
+    calling :obj:`sendNotification`.
 
     In a process which act as a client for a particular bus, a single
     instance of this class is connected to the bus server and provides
     access to the bus for the process.
 
     A process which acts as the server for a particular bus, manages
-    (via the L{BusServer} class) one L{BusConnection} object for each
+    (via the :obj:`BusServer` class) one :obj:`BusConnection` object for each
     client (remote process) connected to the bus.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
+
+    Args:
+
+    Returns:
+
     """
 
     def __init__(self,
-                 host = None, port = None, socket_ = None,
-                 isServer = False, tcpnodelay = True):
+                 host=None, port=None, socket_=None,
+                 isServer=False, tcpnodelay=True):
         """
-        @param host: Hostname or address of the bus server.
-        @type host: str or None
-        @param port: Port of the bus server.
-        @type port: int or None
-        @param socket_: A socket object through which the new
-                        connection should access the bus.
-        @param isServer: if True, the created object will perform the server
-                         part of the handshake protocol.
-        @type isServer: bool
-        @param tcpnodelay: If True, the socket will be set to TCP_NODELAY.
-        @type tcpnodelay: bool
-        @see: L{getBusClientFor}, L{getBusServerFor}.
+        Args:
+            host (str or None):
+                Hostname or address of the bus server.
+            port (int or None):
+                Port of the bus server.
+            socket_:
+                A socket object through which the new connection should access
+                the bus.
+            isServer (bool):
+                if True, the created object will perform the server part of the
+                handshake protocol.
+            tcpnodelay (bool):
+                If True, the socket will be set to TCP_NODELAY.
+
+        See Also:
+            :obj:`getBusClientFor`, :obj:`getBusServerFor`.
         """
         super(BusConnection, self).__init__()
 
@@ -84,25 +94,25 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
 
         self.__thread = None
         self.__socket = None
-        self.__file   = None
+        self.__file = None
 
         self.__errorHook = None
 
         self.__active = False
         self.__activeShutdown = False
-        
+
         self.__lock = threading.RLock()
 
         # Create a socket connection or store the provided connection.
-        if not host is None and not port is None:
+        if host is not None and port is not None:
             if socket_ is None:
                 self.__socket = socket.create_connection((host, port))
             else:
-                raise ValueError, 'specify either host and port or socket'
-        elif not socket_ is None:
+                raise ValueError('Specify either host and port or socket')
+        elif socket_ is not None:
             self.__socket = socket_
         else:
-            raise ValueError, 'specify either host and port or socket_'
+            raise ValueError('Specify either host and port or socket_')
         if tcpnodelay:
             self.__socket.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
         else:
@@ -114,9 +124,9 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
             self.__file.write('\0\0\0\0')
             self.__file.flush()
         else:
-            zero = self.__file.read(size = 4)
+            zero = self.__file.read(size=4)
             if len(zero) == '\0\0\0\0':
-                raise RuntimeError, 'incorrect handshake'
+                raise RuntimeError('Incorrect handshake')
 
     def __del__(self):
         if self.__active:
@@ -133,23 +143,26 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
     # receiving
 
     def receiveNotification(self):
-        size = self.__file.read(size = 4)
+        size = self.__file.read(size=4)
         if len(size) == 0:
             self.__logger.info("Received EOF")
             raise EOFError()
         if not (len(size) == 4):
-            raise RuntimeError, 'short read when receiving notification size (size: %s)' % len(size)
+            raise RuntimeError('Short read when receiving notification size '
+                               '(size: %s)' % len(size))
         size = ord(size[0])      \
             | ord(size[1]) << 8  \
             | ord(size[2]) << 16 \
             | ord(size[3]) << 24
         self.__logger.debug('Receiving notification of size %d', size)
-        notification = self.__file.read(size = size)
+        notification = self.__file.read(size=size)
         if not (len(notification) == size):
-            raise RuntimeError, 'short read when receiving notification payload'
+            raise RuntimeError(
+                'Short read when receiving notification payload')
         return notification
 
-    def bufferToNotification(self, serialized):
+    @staticmethod
+    def bufferToNotification(serialized):
         notification = Notification()
         notification.ParseFromString(serialized)
         return notification
@@ -173,7 +186,7 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
                 self.__logger.warn('Receive error: %s', e)
                 break
 
-        if not self.errorHook is None:
+        if self.errorHook is not None:
             self.errorHook(e)
         return
 
@@ -191,7 +204,8 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
             self.__file.write(notification)
             self.__file.flush()
 
-    def notificationToBuffer(self, notification):
+    @staticmethod
+    def notificationToBuffer(notification):
         return notification.SerializeToString()
 
     def handle(self, notification):
@@ -202,13 +216,13 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
 
     def activate(self):
         if self.__active:
-            raise RuntimeError, 'trying to activate active connection'
+            raise RuntimeError('Trying to activate active connection')
 
         with self.__lock:
 
-            self.__thread = threading.Thread(target = self.receiveNotifications)
+            self.__thread = threading.Thread(target=self.receiveNotifications)
             self.__thread.start()
-    
+
             self.__active = True
 
     def shutdown(self):
@@ -219,12 +233,12 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
     def deactivate(self):
 
         with self.__lock:
-        
+
             if not self.__active:
-                raise RuntimeError, 'trying to deactivate inactive connection'
-    
+                raise RuntimeError('Trying to deactivate inactive connection')
+
             self.__active = False
-    
+
             # If necessary, close the socket, this will cause an exception
             # in the notification receiver thread (unless we run in the
             # context that thread).
@@ -239,7 +253,8 @@ class BusConnection (rsb.eventprocessing.BroadcastProcessor):
         self.__logger.info('Joining thread')
         self.__thread.join()
 
-class Bus (object):
+
+class Bus(object):
     """
     Instances of this class provide access to a socket-based bus.
 
@@ -248,19 +263,19 @@ class Bus (object):
     server as a client.
 
     In-direction connectors add themselves as event sinks using the
-    L{addConnector} method.
+    :obj:`addConnector` method.
 
     Out-direction connectors submit events to the bus using the
-    L{handleOutgoing} method.
+    :obj:`handleOutgoing` method.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
     def __init__(self):
         self.__logger = rsb.util.getLoggerByClass(self.__class__)
 
         self.__connections = []
-        self.__connectors  = []
-        self.__lock        = threading.RLock()
+        self.__connectors = []
+        self.__lock = threading.RLock()
 
         self.__active = False
 
@@ -271,52 +286,61 @@ class Bus (object):
 
     def getConnections(self):
         """
-        @return: A list of all connections to the bus.
-        @rtype: list
+        Returns:
+            list:
+                A list of all connections to the bus.
         """
         return self.__connections
 
     def addConnection(self, connection):
         """
-        Add B{connection} to the list of connections of this bus. This
+        Add ``connection`` to the list of connections of this bus. This
         cause notifications send over this bus to be send through
-        B{connection} and notifications received via B{connection} to
+        ``connection`` and notifications received via ``connection`` to
         be dispatched to connectors of this bus.
 
-        @param connection: The connection that should be added to this
-                           bus.
+        Args:
+            connection:
+                The connection that should be added to this bus.
         """
         with self.lock:
             self.__connections.append(connection)
+
             class Handler(object):
+
                 def __init__(_self):
                     _self.bus = self
+
                 def __call__(_self, notification):
-                    self.handleIncoming(( connection, notification ))
+                    self.handleIncoming((connection, notification))
             connection.addHandler(Handler())
+
             def removeAndDeactivate(exception):
                 self.removeConnection(connection)
                 try:
                     connection.deactivate()
                 except Exception, e:
-                    self.__logger.warning("Error while deactivating connection %s: %s", connection, e)
+                    self.__logger.warning(
+                        "Error while deactivating connection %s: %s",
+                        connection, e)
             connection.errorHook = removeAndDeactivate
             connection.activate()
 
     def removeConnection(self, connection):
         """
-        Remove B{connection} from the list of connections of this bus.
+        Remove ``connection`` from the list of connections of this bus.
 
-        @param connection: The connection that should be removed from
-                           this bus.
+        Args:
+            connection:
+                The connection that should be removed from this bus.
         """
         self.__logger.info('Removing connection %s', connection)
 
         with self.lock:
             if connection in self.__connections:
                 self.__connections.remove(connection)
-                connection.removeHandler([ h for h in connection.handlers
-                                       if h.bus is self ][0])
+                connection.removeHandler([h for h in connection.handlers
+                                          if h.bus is self][0])
 
     connections = property(getConnections)
 
@@ -325,13 +349,14 @@ class Bus (object):
 
     def addConnector(self, connector):
         """
-        Add B{connector} to the list of connectors of this
-        bus. Depending on the direction of B{connector}, this causes
-        B{connector} to either receive or broadcast notifications via
+        Add ``connector`` to the list of connectors of this
+        bus. Depending on the direction of ``connector``, this causes
+        ``connector`` to either receive or broadcast notifications via
         this bus.
 
-        @param connector: The connector that should be added to this
-                          bus.
+        Args:
+            connector:
+                The connector that should be added to this bus.
         """
         self.__logger.info('Adding connector %s', connector)
         with self.lock:
@@ -339,28 +364,33 @@ class Bus (object):
 
     def removeConnector(self, connector):
         """
-        Remove B{connector} from the list of connectors of this bus.
+        Remove ``connector`` from the list of connectors of this bus.
 
-        @param connector: The connector that should be removed from
-                          this bus.
+        Args:
+            connector:
+                The connector that should be removed from this bus.
         """
         self.__logger.info('Removing connector %s', connector)
         with self.lock:
             self.__connectors.remove(connector)
             if not self.__connectors:
-                self.__logger.info('Removed last connector; requesting deletion')
+                self.__logger.info(
+                    'Removed last connector; requesting deletion')
                 return False
             return True
 
     connectors = property(getConnectors)
 
     def handleIncoming(self, connectionAndNotification):
-        (connection, notification) = connectionAndNotification
+        _, notification = connectionAndNotification
         self.__logger.debug('Trying to distribute notification to connectors')
         with self.lock:
-            self.__logger.debug('Locked bus to distribute notification to connectors')
+            self.__logger.debug(
+                'Locked bus to distribute notification to connectors')
             if not self.__active:
-                self.__logger.info('Cancelled distribution to connectors since bus is not active')
+                self.__logger.info(
+                    'Cancelled distribution to connectors '
+                    'since bus is not active')
                 return
 
             # Distribute the notification to participants in our
@@ -369,9 +399,11 @@ class Bus (object):
 
     def handleOutgoing(self, notification):
         with self.lock:
-            self.__logger.debug('Locked bus to distribute notification to connections and connectors')
+            self.__logger.debug('Locked bus to distribute notification to '
+                                'connections and connectors')
             if not self.__active:
-                self.__logger.info('Cancelled distribution to connections and connectors since bus is not active')
+                self.__logger.info('Cancelled distribution to connections '
+                                   'and connectors since bus is not active')
                 return
 
             # Distribute the notification to remote participants via
@@ -389,14 +421,14 @@ class Bus (object):
 
     def activate(self):
         if self.__active:
-            raise RuntimeError, 'Trying to activate active bus'
+            raise RuntimeError('Trying to activate active bus')
 
         with self.lock:
             self.__active = True
 
     def deactivate(self):
         if not self.__active:
-            raise RuntimeError, 'Trying to deactivate inactive bus'
+            raise RuntimeError('Trying to deactivate inactive bus')
 
         with self.lock:
             self.__active = False
@@ -417,15 +449,17 @@ class Bus (object):
 
     # Low-level helpers
 
-    def _toConnections(self, notification, exclude = None):
+    def _toConnections(self, notification, exclude=None):
         failing = []
         for connection in self.connections:
-            if not connection is exclude:
+            if connection is not exclude:
                 try:
                     connection.handle(notification)
                 except Exception, e:
-                    self.__logger.warn('Failed to send to %s: %s; will close connection later',
-                                       connection, e)
+                    self.__logger.warn(
+                        'Failed to send to %s: %s; '
+                        'will close connection later',
+                        connection, e)
                     failing.append(connection)
 
         # Removed connections for which sending the notification
@@ -443,8 +477,8 @@ class Bus (object):
         for connector in self.connectors:
             # TODO connector.direction == 'in' instead of isinstance
             if isinstance(connector, InPushConnector) \
-               and (connector.scope == scope \
-                    or connector.scope.isSuperScopeOf(scope)):
+               and (connector.scope == scope or
+                    connector.scope.isSuperScopeOf(scope)):
                 connector.handle(notification)
 
     def __repr__(self):
@@ -457,23 +491,24 @@ class Bus (object):
 __busClients = {}
 __busClientsLock = threading.Lock()
 
+
 def getBusClientFor(host, port, tcpnodelay, connector):
     """
-    Return (creating it if necessary), a L{BusClient} for the endpoint
-    designated by B{host} and B{port} and attach B{connector} to
-    it. Attaching B{connector} marks the bus client as being in use
+    Return (creating it if necessary), a :obj:`BusClient` for the endpoint
+    designated by ``host`` and ``port`` and attach ``connector`` to
+    it. Attaching ``connector`` marks the bus client as being in use
     and protects it from being destroyed in a race condition
     situation.
 
-    @param host: A hostname or address of the node on which the bus
-                 server listens.
-    @type host: str
-    @param port: The port on which the bus server listens.
-    @type port: int
-    @param tcpnodelay: If True, the socket will be set to TCP_NODELAY.
-    @type tcpnodelay: bool
-    @param connector: A connector that should be attached to the bus
-                      client.
+    Args:
+        host (str):
+            A hostname or address of the node on which the bus server listens.
+        port (int):
+            The port on which the bus server listens.
+        tcpnodelay (bool):
+            If True, the socket will be set to TCP_NODELAY.
+        connector:
+            A connector that should be attached to the bus client.
     """
     key = (host, port, tcpnodelay)
     with __busClientsLock:
@@ -487,22 +522,24 @@ def getBusClientFor(host, port, tcpnodelay, connector):
             bus.addConnector(connector)
         return bus
 
-class BusClient (Bus):
+
+class BusClient(Bus):
     """
     Instances of this class provide access to a bus by means of a
     client socket.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
     def __init__(self, host, port, tcpnodelay):
         """
-        @param host: A hostname or address of the node on which the
-                     bus server listens.
-        @type host: str
-        @param port: The port on which the new bus server listens.
-        @type port: int
-        @param tcpnodelay: If True, the socket will be set to TCP_NODELAY.
-        @type tcpnodelay: bool
+        Args:
+            host (str):
+                A hostname or address of the node on which the bus server
+                listens.
+            port (int):
+                The port on which the new bus server listens.
+            tcpnodelay (bool):
+                If True, the socket will be set to TCP_NODELAY.
         """
         super(BusClient, self).__init__()
 
@@ -511,25 +548,26 @@ class BusClient (Bus):
 __busServers = {}
 __busServersLock = threading.Lock()
 
+
 def getBusServerFor(host, port, tcpnodelay, connector):
     """
-    Return (creating it if necessary), a L{BusServer} for the endpoint
-    designated by B{host} and B{port} and attach B{connector} to
-    it. Attaching B{connector} marks the bus server as being in use
+    Return (creating it if necessary), a :obj:`BusServer` for the endpoint
+    designated by ``host`` and ``port`` and attach ``connector`` to
+    it. Attaching ``connector`` marks the bus server as being in use
     and protects it from being destroyed in a race condition
     situation.
 
-    @param host: A hostname or address identifying the interface to
-                 which the listen socket of the new bus server should
-                 be bound.
-    @type host: str
-    @param port: The port to which the listen socket of the new bus
-                 server should be bound.
-    @type port: int
-    @param tcpnodelay: If True, the socket will be set to TCP_NODELAY.
-    @type tcpnodelay: bool
-    @param connector: A connector that should be attached to the bus
-                      server.
+    Args:
+        host (str):
+            A hostname or address identifying the interface to which the listen
+            socket of the new bus server should be bound.
+        port (int):
+            The port to which the listen socket of the new bus server should be
+            bound.
+        tcpnodelay (bool):
+            If True, the socket will be set to TCP_NODELAY.
+        connector:
+            A connector that should be attached to the bus server.
     """
     key = (host, port, tcpnodelay)
     with __busServersLock:
@@ -543,7 +581,8 @@ def getBusServerFor(host, port, tcpnodelay, connector):
             bus.addConnector(connector)
         return bus
 
-class BusServer (Bus):
+
+class BusServer(Bus):
     """
     Instances of this class provide access to a socket-based bus for
     local and remote bus clients.
@@ -551,37 +590,36 @@ class BusServer (Bus):
     Remote clients can connect to a server socket in order to send and
     receive events through the resulting socket connection.
 
-    Local clients (connectors) use the usual L{Bus} interface to
+    Local clients (connectors) use the usual :obj:`Bus` interface to
     receive events submitted by remote clients and submit events which
-    will be distributed to remote clients by the L{BusServer}.
+    will be distributed to remote clients by the :obj:`BusServer`.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
-    def __init__(self, host, port, tcpnodelay, backlog = 5):
+    def __init__(self, host, port, tcpnodelay, backlog=5):
         """
-        @param host: A hostname or address identifying the interface
-                     to which the listen socket of the new bus server
-                     should be bound.
-        @type host: str
-        @param port: The port to which the listen socket of the new
-                     bus server should be bound.
-        @type port: int
-        @param tcpnodelay: If True, the socket will be set to TCP_NODELAY.
-        @type tcpnodelay: bool
-        @param backlog: The maximum number of queued connection
-                        attempts.
-        @type backlog: int
+        Args:
+            host (str):
+                A hostname or address identifying the interface to which the
+                listen socket of the new bus server should be bound.
+            port (int):
+                The port to which the listen socket of the new bus server
+                should be bound.
+            tcpnodelay (bool):
+                If True, the socket will be set to TCP_NODELAY.
+            backlog (int):
+                The maximum number of queued connection attempts.
         """
         super(BusServer, self).__init__()
 
         self.__logger = rsb.util.getLoggerByClass(self.__class__)
 
-        self.__host           = host
-        self.__port           = port
-        self.__tcpnodelay     = tcpnodelay
-        self.__backlog        = backlog
-        self.__socket         = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        self.__host = host
+        self.__port = port
+        self.__tcpnodelay = tcpnodelay
+        self.__backlog = backlog
+        self.__socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.__acceptorThread = None
 
         self.__active = False
@@ -601,10 +639,13 @@ class BusServer (Bus):
                 if sys.platform == 'darwin':
                     clientSocket.settimeout(None)
                 self.__logger.info('Accepted client %s', addr)
-                self.addConnection(BusConnection(socket_ = clientSocket, isServer = True, tcpnodelay = self.__tcpnodelay))
+                self.addConnection(BusConnection(socket_=clientSocket,
+                                                 isServer=True,
+                                                 tcpnodelay=self.__tcpnodelay))
             except socket.timeout, e:
                 if sys.platform != 'darwin':
-                    self.__logger.error('Unexpected timeout in acceptClients: "%s"', e)
+                    self.__logger.error(
+                        'Unexpected timeout in acceptClients: "%s"', e)
             except Exception, e:
                 if self.__active:
                     self.__logger.error('Exception in acceptClients: "%s"', e,
@@ -621,7 +662,7 @@ class BusServer (Bus):
         # one that sent it.
         (sendingConnection, notification) = connectionAndNotification
         with self.lock:
-            self._toConnections(notification, exclude = sendingConnection)
+            self._toConnections(notification, exclude=sendingConnection)
 
     # State management
 
@@ -629,33 +670,34 @@ class BusServer (Bus):
         super(BusServer, self).activate()
 
         if self.__active:
-            raise RuntimeError, 'trying to activate active BusServer'
+            raise RuntimeError('Trying to activate active BusServer')
 
         # Bind the socket and start listening
-        self.__logger.info('Opening listen socket %s:%d', '0.0.0.0', self.__port)
+        self.__logger.info('Opening listen socket %s:%d',
+                           '0.0.0.0', self.__port)
         self.__socket.bind(('0.0.0.0', self.__port))
         self.__socket.listen(self.__backlog)
 
         self.__logger.info('Starting acceptor thread')
-        self.__acceptorThread = threading.Thread(target = self.acceptClients)
+        self.__acceptorThread = threading.Thread(target=self.acceptClients)
         self.__acceptorThread.start()
 
         self.__active = True
 
     def deactivate(self):
         if not self.__active:
-            raise RuntimeError, 'Trying to deactivate inactive BusServer'
+            raise RuntimeError('Trying to deactivate inactive BusServer')
 
         self.__active = False
 
         # If necessary, close the listening socket. This causes an
         # exception in the acceptor thread.
         self.__logger.info('Closing listen socket')
-        if not self.__socket is None:
+        if self.__socket is not None:
             try:
                 self.__socket.shutdown(socket.SHUT_RDWR)
             except Exception, e:
-                self.__logger.warn('Failed to shutdown listen socket: %s' , e)
+                self.__logger.warn('Failed to shutdown listen socket: %s', e)
             try:
                 self.__socket.close()
             except:
@@ -665,54 +707,62 @@ class BusServer (Bus):
         # The acceptor thread should encounter an exception and exit
         # eventually. We wait for that.
         self.__logger.info('Waiting for acceptor thread')
-        if not self.__acceptorThread is None:
+        if self.__acceptorThread is not None:
             self.__acceptorThread.join()
 
         super(BusServer, self).deactivate()
 
+
 def removeConnector(bus, connector):
-    def removeAndMaybeKill(lock, dict):
+    def removeAndMaybeKill(lock, dictionary):
         with lock:
             if not bus.removeConnector(connector):
                 bus.deactivate()
-                del dict[ [ key for (key, value) in dict.items() if value is bus][0] ]
+                del dictionary[[key for (key, value) in dictionary.items()
+                                if value is bus][0]]
 
     if isinstance(bus, BusClient):
         removeAndMaybeKill(__busClientsLock, __busClients)
     else:
         removeAndMaybeKill(__busServersLock, __busServers)
 
+
 class Connector(rsb.transport.Connector,
                 rsb.transport.ConverterSelectingConnector):
     """
     Instances of subclasses of this class receive events from a bus
-    (represented by a L{Bus} object) that is accessed via a socket
+    (represented by a :obj:`Bus` object) that is accessed via a socket
     connection.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
-    def __init__(self, converters, options = {}, **kwargs):
-        super(Connector, self).__init__(wireType   = bytearray,
-                                        converters = converters,
+    def __init__(self, converters, options=None, **kwargs):
+        super(Connector, self).__init__(wireType=bytearray,
+                                        converters=converters,
                                         **kwargs)
         self.__logger = rsb.util.getLoggerByClass(self.__class__)
 
+        if options is None:
+            options = {}
+
         self.__active = False
 
-        self.__bus        = None
-        self.__host       = options.get('host', 'localhost')
-        self.__port       = int(options.get('port', '55555'))
-        self.__tcpnodelay = options.get('nodelay', '1') in [ '1', 'true' ]
+        self.__bus = None
+        self.__host = options.get('host', 'localhost')
+        self.__port = int(options.get('port', '55555'))
+        self.__tcpnodelay = options.get('nodelay', '1') in ['1', 'true']
         serverString = options.get('server', 'auto')
-        if serverString in [ '1', 'true' ]:
+        if serverString in ['1', 'true']:
             self.__server = True
-        elif serverString in [ '0', 'false']:
+        elif serverString in ['0', 'false']:
             self.__server = False
         elif serverString == 'auto':
             self.__server = 'auto'
         else:
-            raise TypeError, 'server option has to be "1", "true", "0", "false" or "auto", not "%s"' % serverString
+            raise TypeError('Server option has to be '
+                            '"1", "true", "0", "false" or "auto", not "%s"'
+                            % serverString)
 
     def __del__(self):
         if self.__active:
@@ -729,16 +779,20 @@ class Connector(rsb.transport.Connector,
             self.__bus = getBusClientFor(host, port, tcpnodelay, self)
         elif server == 'auto':
             try:
-                self.__logger.info('Trying to get bus server %s:%d (in server = auto mode)',
-                                   host, port)
+                self.__logger.info(
+                    'Trying to get bus server %s:%d (in server = auto mode)',
+                    host, port)
                 self.__bus = getBusServerFor(host, port, tcpnodelay, self)
             except Exception, e:
                 self.__logger.info('Failed to get bus server: %s', e)
-                self.__logger.info('Trying to get bus client %s:%d (in server = auto mode)',
-                                   host, port)
+                self.__logger.info(
+                    'Trying to get bus client %s:%d (in server = auto mode)',
+                    host, port)
                 self.__bus = getBusClientFor(host, port, tcpnodelay, self)
         else:
-            raise TypeError, 'server argument has to be True, False or "auto", not "%s"' % server
+            raise TypeError(
+                'Server argument has to be True, False or "auto", not "%s"'
+                % server)
         self.__logger.info('Got %s', self.__bus)
         return self.__bus
 
@@ -749,17 +803,20 @@ class Connector(rsb.transport.Connector,
 
     def activate(self):
         if self.__active:
-            raise RuntimeError, 'trying to activate active connector'
+            raise RuntimeError('Trying to activate active connector')
 
         self.__logger.info('Activating')
 
-        self.__bus = self.__getBus(self.__host, self.__port, self.__tcpnodelay, self.__server)
+        self.__bus = self.__getBus(self.__host,
+                                   self.__port,
+                                   self.__tcpnodelay,
+                                   self.__server)
 
         self.__active = True
 
     def deactivate(self):
         if not self.__active:
-            raise RuntimeError, 'trying to deactivate inactive connector'
+            raise RuntimeError('Trying to deactivate inactive connector')
 
         self.__logger.info('Deactivating')
 
@@ -770,19 +827,24 @@ class Connector(rsb.transport.Connector,
     def setQualityOfServiceSpec(self, qos):
         pass
 
-class InPushConnector (Connector,
-                       rsb.transport.InConnector):
+    def getTransportURL(self):
+        query = '?tcpnodelay=' + ('1' if self.__tcpnodelay else '0')
+        return 'socket://' + self.__host + ':' + str(self.__port) + query
+
+
+class InPushConnector(Connector,
+                      rsb.transport.InConnector):
     """
     Instances of this class receive events from a bus (represented by
-    a L{Bus} object) that is accessed via a socket connection.
+    a :obj:`Bus` object) that is accessed via a socket connection.
 
     The receiving and dispatching of events is done in push mode: each
-    instance has a L{Bus} which pushes appropriate events into the
+    instance has a :obj:`Bus` which pushes appropriate events into the
     instance. The connector deserializes event payloads and pushes the
     events into handlers (usually objects which implement some event
     processing strategy).
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self, **kwargs):
@@ -790,7 +852,7 @@ class InPushConnector (Connector,
 
         super(InPushConnector, self).__init__(**kwargs)
 
-    def filterNotify(self, filter, action):
+    def filterNotify(self, theFilter, action):
         pass
 
     def setObserverAction(self, action):
@@ -801,19 +863,21 @@ class InPushConnector (Connector,
             return
 
         converter = self.getConverterForWireSchema(notification.wire_schema)
-        event = conversion.notificationToEvent(notification,
-                                               wireData   = bytearray(notification.data),
-                                               wireSchema = notification.wire_schema,
-                                               converter  = converter)
+        event = conversion.notificationToEvent(
+            notification,
+            wireData=bytearray(notification.data),
+            wireSchema=notification.wire_schema,
+            converter=converter)
         self.__action(event)
 
-class OutConnector (Connector,
-                    rsb.transport.OutConnector):
+
+class OutConnector(Connector,
+                   rsb.transport.OutConnector):
     """
     Instance of this class send events to a bus (represented by a
-    L{Bus} object) that is accessed via a socket connection.
+    :obj:`Bus` object) that is accessed via a socket connection.
 
-    @author: jmoringe
+    .. codeauthor:: jmoringe
     """
 
     def __init__(self, **kwargs):
@@ -827,15 +891,16 @@ class OutConnector (Connector,
         wireData, wireSchema = converter.serialize(event.data)
         notification = Notification()
         conversion.eventToNotification(notification, event,
-                                       wireSchema = wireSchema,
-                                       data       = wireData)
+                                       wireSchema=wireSchema,
+                                       data=wireData)
         self.bus.handleOutgoing(notification)
 
+
 class TransportFactory(rsb.transport.TransportFactory):
     """
-    L{TransportFactory} implementation for the socket transport.
+    :obj:`TransportFactory` implementation for the socket transport.
 
-    @author: jwienke
+    .. codeauthor:: jwienke
     """
 
     def getName(self):
@@ -847,6 +912,7 @@ class TransportFactory(rsb.transport.TransportFactory):
     def createOutConnector(self, converters, options):
         return OutConnector(converters=converters, options=options)
 
+
 def initialize():
     try:
         rsb.transport.registerTransport(TransportFactory())
